# 0.1.0

- Initial release

# 0.2.0

- Add uniffi bindings
  
# 0.2.6

- Fix bug in astronomical calendar where noon was calculated incorrectly

# 0.2.7

- Add get_hours, get_minutes, and get_chalakim methods to MoladData